@@ -3,9 +3,11 @@ package bundle
 import (
 	"archive/tar"
 	"bytes"
+	"crypto/sha256"
 	"errors"
 	"fmt"
 	"io"
+	"sort"
 	"strings"
 	"time"
 
@@ -21,7 +23,7 @@ import (
 
 // BuildTektonBundle will return a complete OCI Image usable as a Tekton Bundle built by parsing, decoding, and
 // compressing the provided contents as Tekton objects.
-func BuildTektonBundle(contents []string, annotations map[string]string, log io.Writer) (v1.Image, error) {
+func BuildTektonBundle(contents []string, annotations map[string]string, ctime time.Time, log io.Writer) (v1.Image, error) {
 	img := mutate.Annotations(empty.Image, annotations).(v1.Image)
 
 	if len(contents) > tkremote.MaximumBundleObjects {
@@ -30,6 +32,15 @@ func BuildTektonBundle(contents []string, annotations map[string]string, log io.
 
 	fmt.Fprint(log, "Creating Tekton Bundle:\n")
 
+	// sort the contents based on the digest of the content, this keeps the layer
+	// order in the image manifest deterministic
+	sort.Slice(contents, func(i, j int) bool {
+		iDigest := sha256.Sum256([]byte(contents[i]))
+		jDigest := sha256.Sum256([]byte(contents[j]))
+
+		return bytes.Compare(iDigest[:], jDigest[:]) < 0
+	})
+
 	// For each block of input, attempt to parse all of the YAML/JSON objects as Tekton objects and compress them into
 	// the OCI image as a tar layer.
 	for _, content := range contents {
@@ -85,7 +96,7 @@ func BuildTektonBundle(contents []string, annotations map[string]string, log io.
 	}
 
 	// Set created time for bundle image
-	img, err := mutate.CreatedAt(img, v1.Time{Time: time.Now()})
+	img, err := mutate.CreatedAt(img, v1.Time{Time: ctime})
 	if err != nil {
 		return nil, fmt.Errorf("failed to add created time to image: %w", err)
 	}
