@@ -117,13 +117,13 @@ func TestPipelineDelete_v1beta1(t *testing.T) {
 	}
 
 	type clients struct {
-		pipelineClient pipelinetest.Clients
+		pipelineClient test.Clients
 		dynamicClient  dynamic.Interface
 	}
 	seeds := make([]clients, 0)
 
 	for i := 0; i < 11; i++ {
-		cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+		cs, _ := test.SeedV1beta1TestData(t, test.Data{
 			Pipelines:    pdata,
 			PipelineRuns: prdata,
 			Namespaces: []*corev1.Namespace{
@@ -154,7 +154,7 @@ func TestPipelineDelete_v1beta1(t *testing.T) {
 		name        string
 		command     []string
 		dynamic     dynamic.Interface
-		input       pipelinetest.Clients
+		input       test.Clients
 		inputStream io.Reader
 		wantError   bool
 		want        string
@@ -433,13 +433,13 @@ func TestPipelineDelete(t *testing.T) {
 	}
 
 	type clients struct {
-		pipelineClient test.Clients
+		pipelineClient pipelinetest.Clients
 		dynamicClient  dynamic.Interface
 	}
 	seeds := make([]clients, 0)
 
 	for i := 0; i < 11; i++ {
-		cs, _ := test.SeedTestData(t, test.Data{
+		cs, _ := test.SeedTestData(t, pipelinetest.Data{
 			Pipelines:    pdata,
 			PipelineRuns: prdata,
 			Namespaces: []*corev1.Namespace{
@@ -470,7 +470,7 @@ func TestPipelineDelete(t *testing.T) {
 		name        string
 		command     []string
 		dynamic     dynamic.Interface
-		input       test.Clients
+		input       pipelinetest.Clients
 		inputStream io.Reader
 		wantError   bool
 		want        string
