@@ -125,7 +125,7 @@ func TestPipelineStart_ExecuteCommand_v1beta1(t *testing.T) {
 		},
 	}
 
-	cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{})
+	cs, _ := test.SeedV1beta1TestData(t, test.Data{})
 	cs.Pipeline.Resources = cb.APIResourceList(versionv1beta1, []string{"pipeline", "pipelinerun"})
 	tdc := testDynamic.Options{}
 	dc, err := tdc.Client()
@@ -190,7 +190,7 @@ func TestPipelineStart_ExecuteCommand_v1beta1(t *testing.T) {
 		},
 	}
 
-	cs2, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{Pipelines: pipeline, Namespaces: namespaces})
+	cs2, _ := test.SeedV1beta1TestData(t, test.Data{Pipelines: pipeline, Namespaces: namespaces})
 	cs2.Pipeline.Resources = cb.APIResourceList("v1beta1", []string{"pipeline", "pipelinerun"})
 	tdc2 := testDynamic.Options{}
 	dc2, err := tdc2.Client(
@@ -202,7 +202,7 @@ func TestPipelineStart_ExecuteCommand_v1beta1(t *testing.T) {
 	c2 := &test.Params{Tekton: cs2.Pipeline, Kube: cs2.Kube, Dynamic: dc2, Clock: clock}
 
 	// With list error mocking
-	cs3, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{Pipelines: pipeline, Namespaces: namespaces})
+	cs3, _ := test.SeedV1beta1TestData(t, test.Data{Pipelines: pipeline, Namespaces: namespaces})
 	cs3.Pipeline.Resources = cb.APIResourceList("v1beta1", []string{"pipeline", "pipelinerun"})
 	tdc3 := testDynamic.Options{
 		PrependReactors: []testDynamic.PrependOpt{
@@ -224,7 +224,7 @@ func TestPipelineStart_ExecuteCommand_v1beta1(t *testing.T) {
 	c3 := &test.Params{Tekton: cs3.Pipeline, Kube: cs3.Kube, Dynamic: dc3, Clock: clock}
 
 	// With create error mocking
-	cs4, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{Pipelines: pipeline2, Namespaces: namespaces})
+	cs4, _ := test.SeedV1beta1TestData(t, test.Data{Pipelines: pipeline2, Namespaces: namespaces})
 	cs4.Pipeline.Resources = cb.APIResourceList("v1beta1", []string{"pipeline", "pipelinerun"})
 	tdc4 := testDynamic.Options{
 		PrependReactors: []testDynamic.PrependOpt{
@@ -249,7 +249,7 @@ func TestPipelineStart_ExecuteCommand_v1beta1(t *testing.T) {
 	objs := []runtime.Object{
 		pipeline[0],
 	}
-	seedData, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData, _ := test.SeedV1beta1TestData(t, test.Data{
 		Pipelines:  pipeline,
 		Namespaces: namespaces,
 	})
@@ -269,7 +269,7 @@ func TestPipelineStart_ExecuteCommand_v1beta1(t *testing.T) {
 
 	// pipelineresources data for tests with --filename
 	objs2 := []runtime.Object{}
-	seedData2, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData2, _ := test.SeedV1beta1TestData(t, test.Data{
 		Namespaces: namespaces,
 	})
 	cs6 := pipelinetest.Clients{
@@ -284,7 +284,7 @@ func TestPipelineStart_ExecuteCommand_v1beta1(t *testing.T) {
 	}
 	c6 := &test.Params{Tekton: cs6.Pipeline, Kube: cs6.Kube, Dynamic: dc6, Clock: clock}
 
-	cs7, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{Pipelines: pipeline, Namespaces: namespaces})
+	cs7, _ := test.SeedV1beta1TestData(t, test.Data{Pipelines: pipeline, Namespaces: namespaces})
 	cs7.Pipeline.Resources = cb.APIResourceList(versionv1beta1, []string{"pipeline", "pipelinerun"})
 	tdc7 := testDynamic.Options{}
 	dc7, err := tdc7.Client(
@@ -885,7 +885,7 @@ func TestPipelineStart_ExecuteCommand_v1beta1(t *testing.T) {
 func TestPipelineStart_Interactive_v1beta1(t *testing.T) {
 	t.Skip("Skipping due of flakiness")
 
-	cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	cs, _ := test.SeedV1beta1TestData(t, test.Data{
 		Pipelines: []*v1beta1.Pipeline{
 			{
 				ObjectMeta: metav1.ObjectMeta{
@@ -939,7 +939,7 @@ func TestPipelineStart_Interactive_v1beta1(t *testing.T) {
 		},
 	})
 
-	cs12, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	cs12, _ := test.SeedV1beta1TestData(t, test.Data{
 		Pipelines: []*v1beta1.Pipeline{
 			{
 				ObjectMeta: metav1.ObjectMeta{
@@ -969,7 +969,7 @@ func TestPipelineStart_Interactive_v1beta1(t *testing.T) {
 	testParams := []struct {
 		name               string
 		namespace          string
-		input              pipelinetest.Clients
+		input              test.Clients
 		last               bool
 		serviceAccountName string
 		serviceAccounts    []string
@@ -1265,7 +1265,7 @@ func Test_start_pipeline_v1beta1(t *testing.T) {
 		},
 	}
 
-	cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{Pipelines: pipeline, Namespaces: ns})
+	cs, _ := test.SeedV1beta1TestData(t, test.Data{Pipelines: pipeline, Namespaces: ns})
 	cs.Pipeline.Resources = cb.APIResourceList("v1beta1", []string{"pipeline", "pipelinerun"})
 	tdc := testDynamic.Options{}
 	dc, err := tdc.Client(
@@ -1418,7 +1418,7 @@ func Test_start_pipeline_last_v1beta1(t *testing.T) {
 		},
 	}
 
-	seedData, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData, _ := test.SeedV1beta1TestData(t, test.Data{
 		Namespaces: ns,
 	})
 	cs := pipelinetest.Clients{
@@ -1572,7 +1572,7 @@ func Test_start_pipeline_last_override_timeout_deprecated_v1beta1(t *testing.T)
 		},
 	}
 
-	seedData, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData, _ := test.SeedV1beta1TestData(t, test.Data{
 		Namespaces: ns,
 	})
 	cs := pipelinetest.Clients{
@@ -1703,7 +1703,7 @@ func Test_start_pipeline_last_without_res_param_v1beta1(t *testing.T) {
 		},
 	}
 
-	seedData, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData, _ := test.SeedV1beta1TestData(t, test.Data{
 		Namespaces: ns,
 	})
 	cs := pipelinetest.Clients{
@@ -1846,7 +1846,7 @@ func Test_start_pipeline_last_merge_v1beta1(t *testing.T) {
 		},
 	}
 
-	seedData, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData, _ := test.SeedV1beta1TestData(t, test.Data{
 		Namespaces: ns,
 	})
 	cs := pipelinetest.Clients{
@@ -2007,7 +2007,7 @@ func Test_start_pipeline_use_pipelinerun_v1beta1(t *testing.T) {
 		},
 	}
 
-	seedData, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData, _ := test.SeedV1beta1TestData(t, test.Data{
 		Namespaces: ns,
 	})
 	cs := pipelinetest.Clients{
@@ -2129,7 +2129,7 @@ func Test_start_pipeline_use_pipelinerun_cancelled_status_v1beta1(t *testing.T)
 		},
 	}
 
-	seedData, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData, _ := test.SeedV1beta1TestData(t, test.Data{
 		Namespaces: ns,
 	})
 	cs := pipelinetest.Clients{
@@ -2219,7 +2219,7 @@ func Test_start_pipeline_allkindparam_v1beta1(t *testing.T) {
 		},
 	}
 
-	cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{Pipelines: ps, Namespaces: ns})
+	cs, _ := test.SeedV1beta1TestData(t, test.Data{Pipelines: ps, Namespaces: ns})
 	cs.Pipeline.Resources = cb.APIResourceList("v1beta1", []string{"pipeline", "pipelinerun"})
 	tdc := testDynamic.Options{}
 	dc, err := tdc.Client(
@@ -2362,7 +2362,7 @@ func Test_start_pipeline_last_generate_name_v1beta1(t *testing.T) {
 		},
 	}
 
-	seedData, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData, _ := test.SeedV1beta1TestData(t, test.Data{
 		Namespaces: ns,
 	})
 	cs := pipelinetest.Clients{
@@ -2492,7 +2492,7 @@ func Test_start_pipeline_last_with_prefix_name_v1beta1(t *testing.T) {
 		},
 	}
 
-	seedData, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData, _ := test.SeedV1beta1TestData(t, test.Data{
 		Namespaces: ns,
 	})
 	cs := pipelinetest.Clients{
@@ -2624,7 +2624,7 @@ func Test_start_pipeline_with_prefix_name_v1beta1(t *testing.T) {
 		},
 	}
 
-	seedData, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData, _ := test.SeedV1beta1TestData(t, test.Data{
 		Namespaces: ns,
 	})
 	cs := pipelinetest.Clients{
@@ -2770,7 +2770,7 @@ func Test_lastPipelineRun_v1beta1(t *testing.T) {
 				p: func() *test.Params {
 					clock.Advance(time.Duration(60) * time.Minute)
 
-					cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{PipelineRuns: prs, Namespaces: ns})
+					cs, _ := test.SeedV1beta1TestData(t, test.Data{PipelineRuns: prs, Namespaces: ns})
 					cs.Pipeline.Resources = cb.APIResourceList("v1beta1", []string{"pipeline", "pipelinerun"})
 					tdc := testDynamic.Options{}
 					dc, err := tdc.Client(
@@ -2794,7 +2794,7 @@ func Test_lastPipelineRun_v1beta1(t *testing.T) {
 			args: args{
 				pipeline: "test",
 				p: func() *test.Params {
-					cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{Namespaces: ns})
+					cs, _ := test.SeedV1beta1TestData(t, test.Data{Namespaces: ns})
 					cs.Pipeline.Resources = cb.APIResourceList("v1beta1", []string{"pipeline", "pipelinerun"})
 					tdc := testDynamic.Options{}
 					dc, err := tdc.Client()
@@ -2883,7 +2883,7 @@ func Test_start_pipeline_with_skip_optional_workspace_flag_v1beta1(t *testing.T)
 		},
 	}
 
-	seedData, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{
+	seedData, _ := test.SeedV1beta1TestData(t, test.Data{
 		Namespaces: ns,
 	})
 	cs := pipelinetest.Clients{
