@@ -87,7 +87,7 @@ func TestPipelineRunExport_v1beta1(t *testing.T) {
 	if err != nil {
 		t.Errorf("unable to create dynamic client: %v", err)
 	}
-	cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{Namespaces: namespaces, PipelineRuns: pipelineruns})
+	cs, _ := test.SeedV1beta1TestData(t, test.Data{Namespaces: namespaces, PipelineRuns: pipelineruns})
 	cs.Pipeline.Resources = cb.APIResourceList(version, []string{"pipelinerun"})
 	p := &test.Params{Tekton: cs.Pipeline, Clock: clock, Kube: cs.Kube, Dynamic: dynamic}
 
@@ -155,7 +155,7 @@ func TestPipelineRunExport(t *testing.T) {
 	if err != nil {
 		t.Errorf("unable to create dynamic client: %v", err)
 	}
-	cs, _ := test.SeedTestData(t, test.Data{Namespaces: namespaces, PipelineRuns: pipelineruns})
+	cs, _ := test.SeedTestData(t, pipelinetest.Data{Namespaces: namespaces, PipelineRuns: pipelineruns})
 	cs.Pipeline.Resources = cb.APIResourceList(version, []string{"pipelinerun"})
 	p := &test.Params{Tekton: cs.Pipeline, Clock: clock, Kube: cs.Kube, Dynamic: dynamic}
 
