@@ -37,10 +37,10 @@ const (
 	pipelinesInfo                  string = "pipelines-info"
 	triggersInfo                   string = "triggers-info"
 	dashboardInfo                  string = "dashboard-info"
-	operatorInfo                   string = "operators-info"
+	operatorInfo                   string = "tekton-operator-info"
 )
 
-var defaultNamespaces = []string{"tekton-pipelines", "openshift-pipelines", "tekton-chains"}
+var defaultNamespaces = []string{"tekton-pipelines", "openshift-pipelines", "tekton-chains", "tekton-operator", "openshift-operators"}
 
 // GetPipelineVersion Get pipeline version, functions imported from Dashboard
 func GetPipelineVersion(c *cli.Clients, ns string) (string, error) {
@@ -87,9 +87,8 @@ func getDeployments(c *cli.Clients, newLabel, oldLabel, ns string) (*v1.Deployme
 		if err != nil {
 			if strings.Contains(err.Error(), fmt.Sprintf(`cannot list resource "deployments" in API group "apps" in the namespace "%s"`, n)) {
 				continue
-			} else {
-				return nil, err
 			}
+			return nil, err
 		}
 		if len(deployments.Items) != 0 {
 			break
@@ -136,6 +135,9 @@ func getConfigMap(c *cli.Clients, name, ns string) (*corev1.ConfigMap, error) {
 			if errors.IsNotFound(err) {
 				continue
 			}
+			if strings.Contains(err.Error(), fmt.Sprintf(`cannot get resource "configmaps" in API group "" in the namespace "%s"`, n)) {
+				continue
+			}
 			return nil, err
 		}
 		if configMap != nil {
@@ -284,20 +286,10 @@ func findDashboardVersion(deployments []v1.Deployment) string {
 
 // GetOperatorVersion Get operator version
 func GetOperatorVersion(c *cli.Clients, ns string) (string, error) {
-
-	var version string
 	configMap, err := getConfigMap(c, operatorInfo, ns)
-	if err == nil {
-		version = configMap.Data["version"]
-	}
-
-	if version != "" {
-		return version, nil
-	}
-
 	if err != nil {
 		return "", err
 	}
-
+	version := configMap.Data["version"]
 	return version, nil
 }
